==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/c2/c2fd5ab08467296648261c16353a2f21.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php */
class __TwigTemplate_0760424fe3e97854921ac863dde1f668 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CampaignBundle\\Executioner\\Dispatcher\\Exception;

use Mautic\\CampaignBundle\\Entity\\LeadEventLog;

class LogPassedAndFailedException extends \\Exception
{
    public function __construct(LeadEventLog \$log)
    {
        parent::__construct(\"LeadEventLog ID # {\$log->getId()} was passed to both pass() or fail(). Pass or fail the log, not both.\", 0, null);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/c2/c2fd5ab08467296648261c16353a2f21.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php */
class __TwigTemplate_0760424fe3e97854921ac863dde1f668 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CampaignBundle\\Executioner\\Dispatcher\\Exception;

use Mautic\\CampaignBundle\\Entity\\LeadEventLog;

class LogPassedAndFailedException extends \\Exception
{
    public function __construct(LeadEventLog \$log)
    {
        parent::__construct(\"LeadEventLog ID # {\$log->getId()} was passed to both pass() or fail(). Pass or fail the log, not both.\", 0, null);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php", "/var/www/html/production-demo/app/bundles/CampaignBundle/Executioner/Dispatcher/Exception/LogPassedAndFailedException.php");
    }
}
